@@ -106,7 +106,7 @@ class ScpiTcpIpTransport(ScpiTransportBase):
 
         return f'TCPIP::{host_address}::{host_port}::SOCKET'
 
-    def __init__(self, address: Union[tuple, str], timeout: float=5.0, **kwargs):
+    def __init__(self, address: Union[tuple, str], timeout: float=5.0, ip_family=socket.AF_UNSPEC, **kwargs):
         super().__init__(**kwargs)
         self._logger = logging.getLogger(__name__)
         self._sock = None
@@ -120,9 +120,9 @@ class ScpiTcpIpTransport(ScpiTransportBase):
 
         try:
             # Get address info
-            addr_infos = socket.getaddrinfo(address[0], address[1], type=socket.SOCK_STREAM, proto=socket.IPPROTO_TCP)
+            addr_infos = socket.getaddrinfo(address[0], address[1], family=ip_family, type=socket.SOCK_STREAM, proto=socket.IPPROTO_TCP)
         except socket.gaierror as e:
-            raise ScpiTransportException(e) from e
+            raise ScpiTransportException(f'Host {address[0]} is unknown ({str(e)})')
 
         for addr_info in addr_infos:
             try:
@@ -139,7 +139,7 @@ class ScpiTcpIpTransport(ScpiTransportBase):
                 # Successful, do not try other addresses
                 break
             except OSError as e:
-                self._logger.warning(f'Could not connect to {addr_info[4]}: {str(e)}')
+                self._logger.warning(f'Could not connect to {addr_info[4]} ({str(e)})')
         else:
             # Did not break in for-loop above
             raise ScpiTransportException(f'Connection to host {address[0]} could not be established.')
